
public class IntegrationTrapeze {
    /**
     * Intégration par la méthode des trapèzes
     * 
     * @param n nombre de sous-intervalles
     * @param a borne inférieure d'intégration
     * @param b borne supérieure d'intégration
     * @param f fonction a intégrer
     * @return intégrale de la fonction f sur l'intervalle [a, b]
     */
    public static double integre(int n, double a, double b, FonctionDUneVariable f)
    {
        double deltaX = (b - a)/n;
        double x = a; 
        double somme = 0;
        
        if (f.estDefinie(a) && f.estDefinie(b))
            somme = (f.calculFonctionEn(a) + f.calculFonctionEn(b)) / 2.;
        else throw new ArithmeticException("Fonction non définie");
        
        for(int i=1; i < n; i++)
        {
            x += deltaX;
            if (f.estDefinie(x))
                somme += f.calculFonctionEn(x);
            else throw new ArithmeticException("Fonction non définie");
        }
        return somme * deltaX;
    }
}

